@@ -187,6 +187,7 @@ label_v     <- c('TRUE',
                  )
 numeric2_v <- c('blank',
                  'scatter plot',
+                 'scatter plot with trend line',
                  'bw scatter plot',
                  'color scatter plot',
                  'binned scatter plot',
@@ -226,8 +227,8 @@ numeric2_v <- c('blank',
                  'stepped area graph',
                  'bw stepped area graph',
                  'color stepped area graph',
-                 'bw heatmap',
-                 'color heatmap',
+                 'bw seq. heatmap',
+                 'color seq. heatmap',
                  'bw seq. stripe graph',
                  'color seq. stripe graph',
                  'histogram',
